FileWriter

Struct FileWriter 

pub struct FileWriter {
    pub directory_path: String,
    pub file_name: String,
    pub file_ext: Option<String>,
    pub max_log_files: Option<usize>,
    pub rotation: Option<FileRotation>,
    pub non_blocking: NonBlockingOptions,
}
A file Writer

Example

# declare a writer named "my_file"
[writer.my_file]
type = "file"
directory_path = "${env:fs_app_logs}/rust/" # ${env:fs_app_logs} there should be an environment variable named "fs_app_logs"
file_name = "util"
# The following are optional
file_ext = "log" # filename will end in .log
max_log_files = 50 # keep at most 50 log files
rotation = "daily" # possible values are : "minutely", "hourly", "daily", "never"
# The following are optional and only related to non blocking
non_blocking = true # async
buffered_lines_limit = 2048 # lines buffer
lossy = false # no loss of information/logs
thread_name = "my_file_async_thread"

Fields

directory_path: String

Must point to an existing directory on the file system

file_name: String

The name of the tracing file without file extension

file_ext: Option<String>

The file extension without the . (dot)

max_log_files: Option<usize>

The maximum number of log/tracing files inside of directory_path for this writer. Only valid if FileRotation is not Never

rotation: Option<FileRotation>

File rotation options

non_blocking: NonBlockingOptions

Non blocking options