pub struct NonBlockingOptions {
pub enabled: bool,
pub buffered_lines_limit: Option<usize>,
pub lossy: Option<bool>,
pub thread_name: Option<String>,
}Expand description
tracing appender NonBlocking options
Fields
enabled: boolWhether non blocking is enabled or not
buffered_lines_limit: Option<usize>Number of lines to buffer before dropping logs (only valid if lossy is enabled)
lossy: Option<bool>If set to true, logs will be dropped when the buffered limit (buffered_lines_limit) is reached
thread_name: Option<String>Override the worker thread’s name.