pub struct SiftingLayer<S, L, FnLB>where
S: Subscriber + for<'lookup> LookupSpan<'lookup>,
L: TsLayer<S> + Send + Sync + 'static,
FnLB: FnMut(&Selector, &Values) -> L,{ /* private fields */ }Expand description
A tracing-subscriber Layer that sifts trough spans and forwards events to dynamically created Layers.
Just like all the layers it’s generic over S which is a Subscriber. It is also generic over L which is the dynamically created layer and FnLB (LB stand for Layer Builder) which is the closure responsible to create a new Layer at runtime.
The FnLB will receive a Selector and a SelectorValues and is responsible to create a unique layer for the specific set of SelectorValues.
FnLB will be called once for every distinct set of SelectorValues.
Implementations